@@ -1,13 +1,13 @@
-# hilbe.NBR2.F8.9.r
+# hilbe.NBR2.F8.13.r
 # Negative binomial regression distributions with 
 #    user specified series of alpha values for a specified mean value
 # From Hilbe, Negative Binomial regression, 2nd ed, Cambridge Univ. Press
-# Figures 8.9   default: alpha at 0, .33, .67, 1, 1.5, 3 and mean=2
+# Figures 8.13   default: alpha at 0.6, .8, 1, 1.2 and mean=10
 #
 obs <- 11
-alpha <- c(.009, .33, .67, 1, 1.5, 3)
-y <- 0:10
-mu <- 2
+alpha <- c(.6, .8, 1, 1.2)
+y <- 0:30
+mu <- 10
 amu <- mu*alpha
 layout(1) 
 for (i in 1:length(amu)) { 
@@ -37,3 +37,8 @@ plot(y, ynb2, col=i, type='l', lty=i)
 
 
 
+
+
+
+
+
